@@ -730,3 +730,7 @@ class GNNlearner:
     def get_model(self):
         """Return the target model."""
         return self.target_GNN_model, self.target_Regressor_model
+    
+    def save_weights(self, path):
+        """Save model weights in the specified path."""
+        self.target_model.save_weights(path)
